@@ -1,5 +1,3 @@
-# nocov start
-
 #' Walter & Lieth climatic diagram from normal climatology values
 #'
 #' @description
@@ -38,17 +36,21 @@
 #' @examplesIf aemet_detect_api_key()
 #' climatogram_normal("9434")
 #' @export
-climatogram_normal <- function(station, labels = "en", verbose = FALSE,
-                               ggplot2 = TRUE, ...) {
+climatogram_normal <- function(
+  station,
+  labels = "en",
+  verbose = FALSE,
+  ggplot2 = TRUE,
+  ...
+) {
   if (verbose) {
-    message("Data download may take a few seconds ... please wait \n")
+    cli::cli_alert_info("Data download may take a few seconds ... please wait.")
   }
 
-  data_raw <-
-    aemet_normal_clim(station, verbose = verbose)
+  data_raw <- aemet_normal_clim(station, verbose = verbose)
 
   if (nrow(data_raw) == 0) {
-    stop("No valid results from the API")
+    cli::cli_abort("No valid results from the API")
   }
 
   data <- data_raw[c("mes", "p_mes_md", "tm_max_md", "tm_min_md", "ta_min_min")]
@@ -70,34 +72,36 @@ climatogram_normal <- function(station, labels = "en", verbose = FALSE,
   stations <- aemet_stations(verbose = verbose)
   stations <- stations[stations$indicativo == station, ]
 
-  data_na <- as.integer(sum(is.na(data)))
-
   if (is.null(labels)) {
     labels <- "en"
   }
 
-  if (data_na > 0) {
-    message("Data with null values, unable to plot the diagram \n")
-  } else if (ggplot2 == TRUE) {
+  if (ggplot2 == TRUE) {
     ggclimat_walter_lieth(
       data,
       est = stations$nombre,
       alt = stations$altitud,
-      per = "1981-2010",
+      per = "1981 - 2010",
       mlab = labels,
       ...
     )
   } else {
+    # nocov start
     if (!requireNamespace("climatol", quietly = TRUE)) {
-      stop("\n\npackage climatol required, please install it first")
+      cli::cli_abort("{.pkg climatol} required, please install it first")
     }
+    # nocov end
+
+    data <- as.matrix(data)
+    data <- unname(data)
 
     climatol::diagwl(
       data,
-      est = stations$nombre,
+      stname = stations$nombre,
       alt = stations$altitud,
-      per = "1981-2010",
+      per = "1981 - 2010",
       mlab = labels,
+      cols = NULL,
       ...
     )
   }
@@ -136,19 +140,22 @@ climatogram_normal <- function(station, labels = "en", verbose = FALSE,
 #'
 #' @export
 
-climatogram_period <- function(station = NULL, start = 1990, end = 2020,
-                               labels = "en", verbose = FALSE, ggplot2 = TRUE,
-                               ...) {
-  data_raw <- aemet_monthly_period(station,
+climatogram_period <- function(
+  station = NULL,
+  start = 1990,
+  end = 2020,
+  labels = "en",
+  verbose = FALSE,
+  ggplot2 = TRUE,
+  ...
+) {
+  data_raw <- aemet_monthly_period(
+    station,
     start = start,
     end = end,
     verbose = verbose
   )
 
-  if (nrow(data_raw) == 0) {
-    stop("No valid results from the API")
-  }
-
   data <- data_raw[c("fecha", "p_mes", "tm_max", "tm_min", "ta_min")]
   data <- tidyr::drop_na(data, c("p_mes", "tm_max", "tm_min", "ta_min"))
   data <- data[-grep("-13", data$fecha), ]
@@ -176,15 +183,11 @@ climatogram_period <- function(station = NULL, start = 1990, end = 2020,
   stations <- aemet_stations(verbose = verbose)
   stations <- stations[stations$indicativo == station, ]
 
-  data_na <- as.integer(sum(is.na(data)))
-
   if (is.null(labels)) {
     labels <- "en"
   }
 
-  if (data_na > 0) {
-    message("Data with null values, unable to plot the diagram \n")
-  } else if (ggplot2) {
+  if (ggplot2) {
     ggclimat_walter_lieth(
       data,
       est = stations$nombre,
@@ -194,21 +197,28 @@ climatogram_period <- function(station = NULL, start = 1990, end = 2020,
       ...
     )
   } else {
+    # nocov start
     if (!requireNamespace("climatol", quietly = TRUE)) {
-      stop("\n\npackage climatol required, please install it first")
+      cli::cli_abort("{.pkg climatol} required, please install it first")
     }
+    # nocov end
 
-    climatol::diagwl(data,
-      est = stations$nombre,
-      alt = stations$altitud, per = paste(start, "-", end),
-      mlab = labels, cols = NULL, ...
+    data <- as.matrix(data)
+    data <- unname(data)
+
+    climatol::diagwl(
+      data,
+      stname = stations$nombre,
+      alt = stations$altitud,
+      per = paste(start, "-", end),
+      mlab = labels,
+      cols = NULL,
+      ...
     )
   }
 }
 
 
-
-
 #' Walter and Lieth climatic diagram on \CRANpkg{ggplot2}
 #'
 #' @description
@@ -289,32 +299,47 @@ climatogram_period <- function(station = NULL, start = 1990, end = 2020,
 #'     face = "bold"
 #'   )
 #' )
-ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
-                                  mlab = "es", pcol = "#002F70",
-                                  tcol = "#ff0000", pfcol = "#9BAEE2",
-                                  sfcol = "#3C6FC4", shem = FALSE,
-                                  p3line = FALSE,
-                                  ...) {
+ggclimat_walter_lieth <- function(
+  dat,
+  est = "",
+  alt = NA,
+  per = NA,
+  mlab = "es",
+  pcol = "#002F70",
+  tcol = "#ff0000",
+  pfcol = "#9BAEE2",
+  sfcol = "#3C6FC4",
+  shem = FALSE,
+  p3line = FALSE,
+  ...
+) {
   ## Validate inputs----
 
   if (!all(dim(dat) == c(4, 12))) {
-    stop(
-      "`dat` should have 4 rows and 12 colums. Your inputs has ",
-      nrow(dat), " rows and ", ncol(dat), " columns."
+    cli::cli_abort(
+      paste0(
+        "{.arg dat} should have {.code dim(dat)} 4 and 12. ",
+        "The {.fn base::dim} of your input are {dim(dat)}."
+      )
     )
   }
 
   # NULL data
   data_na <- as.integer(sum(is.na(dat)))
   if (data_na > 0) {
-    stop("Data with null values, unable to plot the diagram \n")
+    cli::cli_abort(
+      "Data with NULL values, unable to plot the diagram."
+    )
   }
 
   # If matrix transform to data frame
   if (is.matrix(dat)) {
-    dat <- as.data.frame(dat,
+    dat <- as.data.frame(
+      dat,
       row.names = c(
-        "p_mes_md", "tm_max_md", "tm_min_md",
+        "p_mes_md",
+        "tm_max_md",
+        "tm_min_md",
         "ta_min_min"
       ),
       col.names = paste0("m", seq_len(12))
@@ -341,7 +366,8 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
   dat_long$tm <- (dat_long[[3]] + dat_long[[4]]) / 2
 
   # Reescalate p_mes
-  dat_long$pm_reesc <- ifelse(dat_long$p_mes < 100,
+  dat_long$pm_reesc <- ifelse(
+    dat_long$p_mes < 100,
     dat_long$p_mes * 0.5,
     dat_long$p_mes * 0.05 + 45
   )
@@ -378,8 +404,7 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
           y = dat_long[c(j, j + 1), i],
           n = 50
         )
-        val <-
-          as.data.frame(interpol$y) # Just the interpolated value
+        val <- as.data.frame(interpol$y) # Just the interpolated value
       }
       names(val) <- names(dat_long)[i]
       intres <- dplyr::bind_cols(intres, val)
@@ -392,8 +417,7 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
   dat_long_int$interpolate <- TRUE
   dat_long_int$label <- ""
   dat_long$interpolate <- FALSE
-  dat_long_int <-
-    dat_long_int[!dat_long_int$indrow %in% dat_long$indrow, ]
+  dat_long_int <- dat_long_int[!dat_long_int$indrow %in% dat_long$indrow, ]
   dat_long_end <- dplyr::bind_rows(dat_long, dat_long_int)
   dat_long_end <- dat_long_end[order(dat_long_end$indrow), ]
   dat_long_end <- dat_long_end[
@@ -402,8 +426,6 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
   dat_long_end <- tibble::as_tibble(dat_long_end)
   # Final tibble with normalized and helper values
 
-
-
   # Labels and axis----
 
   ## Horizontal axis ----
@@ -438,8 +460,10 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
 
   if (!is.na(alt)) {
     title <- paste0(
-      title, " (",
-      prettyNum(alt, big.mark = ",", decimal.mark = "."), " m)"
+      title,
+      " (",
+      prettyNum(alt, big.mark = ",", decimal.mark = "."),
+      " m)"
     )
   }
 
@@ -448,18 +472,18 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
   }
 
   # Subtitles
-  sub <-
-    paste(round(mean(dat_long_end[dat_long_end$interpolate == FALSE, ]$tm), 1),
-      "C        ",
-      prettyNum(
-        round(sum(
-          dat_long_end[dat_long_end$interpolate == FALSE, ]$p_mes
-        )),
-        big.mark = ","
-      ),
-      " mm",
-      sep = ""
-    )
+  sub <- paste(
+    round(mean(dat_long_end[dat_long_end$interpolate == FALSE, ]$tm), 1),
+    "C        ",
+    prettyNum(
+      round(sum(
+        dat_long_end[dat_long_end$interpolate == FALSE, ]$p_mes
+      )),
+      big.mark = ","
+    ),
+    " mm",
+    sep = ""
+  )
 
   # Vertical tags
   maxtm <- prettyNum(round(max(dat_long_end$tm_max), 1))
@@ -480,9 +504,6 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
     ymax = 0
   )
 
-
-
-
   # Lines and additional areas----
   getpolymax <- function(x, y, y_lim) {
     initpoly <- FALSE
@@ -490,7 +511,7 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
     xres <- NULL
 
     # Check
-    for (i in seq_len(length(y))) {
+    for (i in seq_along(y)) {
       lastobs <- i == length(x)
 
       # If conditions to plot polygon
@@ -519,17 +540,16 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
       }
     }
     poly <- tibble::tibble(x = xres, y = yres)
-    return(poly)
+    poly
   }
 
-
   getlines <- function(x, y, y_lim) {
     yres <- NULL
     xres <- NULL
     ylim_res <- NULL
 
     # Check
-    for (i in seq_len(length(y))) {
+    for (i in seq_along(y)) {
       # If conditions to line
       if (y[i] > y_lim[i]) {
         xres <- c(xres, x[i])
@@ -542,7 +562,7 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
       y = yres,
       ylim_res = ylim_res
     )
-    return(line)
+    line
   }
 
   prep_max_poly <- getpolymax(
@@ -564,20 +584,21 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
   )
 
   # Prob freeze
-  dat_real <-
-    dat_long_end[dat_long_end$interpolate == FALSE, c("indrow", "ta_min")]
+  dat_real <- dat_long_end[
+    dat_long_end$interpolate == FALSE,
+    c("indrow", "ta_min")
+  ]
   x <- NULL
   y <- NULL
   for (i in seq_len(nrow(dat_real))) {
     if (dat_real[i, ]$ta_min < 0) {
-      x <-
-        c(
-          x,
-          NA,
-          rep(dat_real[i, ]$indrow - 0.5, 2),
-          rep(dat_real[i, ]$indrow + 0.5, 2),
-          NA
-        )
+      x <- c(
+        x,
+        NA,
+        rep(dat_real[i, ]$indrow - 0.5, 2),
+        rep(dat_real[i, ]$indrow + 0.5, 2),
+        NA
+      )
       y <- c(y, NA, -3, 0, 0, -3, NA)
     } else {
       x <- c(x, NA)
@@ -587,21 +608,22 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
   probfreeze <- tibble::tibble(x = x, y = y)
   rm(dat_real)
   # Sure freeze
-  dat_real <-
-    dat_long_end[dat_long_end$interpolate == FALSE, c("indrow", "tm_min")]
+  dat_real <- dat_long_end[
+    dat_long_end$interpolate == FALSE,
+    c("indrow", "tm_min")
+  ]
 
   x <- NULL
   y <- NULL
   for (i in seq_len(nrow(dat_real))) {
     if (dat_real[i, ]$tm_min < 0) {
-      x <-
-        c(
-          x,
-          NA,
-          rep(dat_real[i, ]$indrow - 0.5, 2),
-          rep(dat_real[i, ]$indrow + 0.5, 2),
-          NA
-        )
+      x <- c(
+        x,
+        NA,
+        rep(dat_real[i, ]$indrow - 0.5, 2),
+        rep(dat_real[i, ]$indrow + 0.5, 2),
+        NA
+      )
       y <- c(y, NA, -3, 0, 0, -3, NA)
     } else {
       x <- c(x, NA)
@@ -617,7 +639,32 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
       data = dat_long_end,
       aes(x = .data$indrow, y = .data$pm_reesc),
       color = pcol
-    ) +
+    )
+
+  # Probable freeze
+
+  if (min(dat_long_end$ta_min) < 0) {
+    wandlplot <- wandlplot +
+      ggplot2::geom_polygon(
+        data = probfreeze,
+        aes(x = x, y = y),
+        fill = pfcol,
+        colour = "black"
+      )
+  }
+
+  # Sure freeze
+
+  if (min(dat_long_end$tm_min) < 0) {
+    wandlplot <- wandlplot +
+      geom_polygon(
+        data = surefreeze,
+        aes(x = x, y = y),
+        fill = sfcol,
+        colour = "black"
+      )
+  }
+  wandlplot <- wandlplot +
     ggplot2::geom_line(
       data = dat_long_end,
       aes(x = .data$indrow, y = .data$tm),
@@ -672,45 +719,23 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
     wandlplot <- wandlplot +
       ggplot2::geom_polygon(
         data = prep_max_poly,
-        aes(x, y), fill = pcol
+        aes(x, y),
+        fill = pcol
       )
   }
 
-
-  # Probable freeze
-
-  if (min(dat_long_end$ta_min) < 0) {
-    wandlplot <- wandlplot +
-      ggplot2::geom_polygon(
-        data = probfreeze,
-        aes(x = x, y = y),
-        fill = pfcol,
-        colour = "black"
-      )
-  }
-
-  # Sure freeze
-
-  if (min(dat_long_end$tm_min) < 0) {
-    wandlplot <- wandlplot +
-      geom_polygon(
-        data = surefreeze,
-        aes(x = x, y = y),
-        fill = sfcol,
-        colour = "black"
-      )
-  }
-
-
   # Add lines and scales to chart
   wandlplot <- wandlplot +
-    geom_hline(yintercept = c(0, 50), size = 0.5) +
-    geom_segment(data = ticks, aes(
-      x = x,
-      xend = x,
-      y = ymin,
-      yend = ymax
-    )) +
+    geom_hline(yintercept = c(0, 50), linewidth = 0.5) +
+    geom_segment(
+      data = ticks,
+      aes(
+        x = x,
+        xend = x,
+        y = ymin,
+        yend = ymax
+      )
+    ) +
     scale_x_continuous(
       breaks = month_breaks,
       name = "",
@@ -728,7 +753,6 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
       )
     )
 
-
   # Add tags and theme
   wandlplot <- wandlplot +
     ggplot2::labs(
@@ -757,7 +781,7 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
         vjust = 0.9,
         size = 10,
         colour = tcol,
-        margin = unit(rep(10, 4), "pt")
+        margin = ggplot2::margin(10, 10, 10, 10)
       ),
       axis.text.x.bottom = element_text(size = 10),
       axis.text.y.left = element_text(colour = tcol, size = 10),
@@ -766,13 +790,10 @@ ggclimat_walter_lieth <- function(dat, est = "", alt = NA, per = NA,
         vjust = 0.9,
         size = 10,
         colour = pcol,
-        margin = unit(rep(10, 4), "pt")
+        margin = ggplot2::margin(10, 10, 10, 10)
       ),
       axis.text.y.right = element_text(colour = pcol, size = 10)
     )
 
-
-  return(wandlplot)
+  wandlplot
 }
-
-# nocov end
