@@ -20,12 +20,13 @@
 #' dms2decdegrees("055245W")
 #' @export
 dms2decdegrees <- function(input = NULL) {
-  if (is.null(input)) {
-    stop("Input can't be missing")
-  }
-
-  if (!is.character(input)) {
-    stop("Input need to be character string")
+  if (any(is.null(input), !is.character(input))) {
+    cli::cli_abort(
+      paste0(
+        "{.arg input} needs to be character string, ",
+        "not {.obj_type_friendly {input}}."
+      )
+    )
   }
 
   deg <- as.numeric(substr(input, 0, 2))
@@ -35,7 +36,7 @@ dms2decdegrees <- function(input = NULL) {
   x <- ifelse(substr(input, 7, 8) == "W", -x, x)
   x <- ifelse(substr(input, 7, 8) == "S", -x, x)
 
-  return(x)
+  x
 }
 
 #' @rdname dms2decdegrees
@@ -52,8 +53,9 @@ dms2decdegrees_2 <- function(input = NULL) {
   pieces <- as.double(pieces[pieces != ""])
 
   # Check here
-  if (length(pieces) != 3) stop("Something went wrong")
-
+  if (length(pieces) != 3) {
+    cli::cli_abort("Something went wrong.")
+  }
 
   # Convert pieces and sign
   dec <- minus * sum(pieces / c(1, 60, 60^2))
@@ -78,33 +80,34 @@ dms2decdegrees_2 <- function(input = NULL) {
 #' last_day_of_year(2020)
 #' @export
 
-
 first_day_of_year <- function(year = NULL) {
-  if (is.null(year)) {
-    stop("Year can't be missing")
-  }
-
-  if (!is.numeric(year)) {
-    stop("Year need to be numeric")
+  if (any(is.null(year), !is.numeric(year))) {
+    cli::cli_abort(
+      paste0(
+        "{.arg year} needs to be numeric, ",
+        "not {.obj_type_friendly {year}}."
+      )
+    )
   }
 
   date <- as.character(paste0(year, "-01-01"))
 
-  return(date)
+  date
 }
 
 #' @rdname day_of_year
 #' @export
 last_day_of_year <- function(year = NULL) {
-  if (is.null(year)) {
-    stop("Year can't be missing")
-  }
-
-  if (!is.numeric(year)) {
-    stop("Year need to be numeric")
+  if (any(is.null(year), !is.numeric(year))) {
+    cli::cli_abort(
+      paste0(
+        "{.arg year} needs to be numeric, ",
+        "not {.obj_type_friendly {year}}."
+      )
+    )
   }
 
   date <- as.character(paste0(year, "-12-31"))
 
-  return(date)
+  date
 }
