@@ -1,5 +1,3 @@
-# nocov start
-
 #' Station climate stripes graph
 #'
 #' Plot climate stripes graph for a station.
@@ -7,6 +5,7 @@
 #' @family aemet_plots
 #' @family stripes
 #'
+#' @rdname climatestripes_station
 #'
 #' @inheritSection aemet_daily_clim API Key
 #'
@@ -37,33 +36,36 @@
 #' }
 #' }
 #' @export
-climatestripes_station <- function(station, start = 1950, end = 2020,
-                                   with_labels = "yes", verbose = FALSE,
-                                   ...) {
-  message("Data download may take a few minutes ... please wait \n")
+climatestripes_station <- function(
+  station,
+  start = 1950,
+  end = 2020,
+  with_labels = "yes",
+  verbose = FALSE,
+  ...
+) {
+  cli::cli_alert_info("Data download may take a few seconds ... please wait.")
 
-
-  data_raw <-
-    aemet_monthly_period(station,
-      start = start,
-      end = end,
-      verbose = verbose
-    )
+  data_raw <- aemet_monthly_period(
+    station,
+    start = start,
+    end = end,
+    verbose = verbose
+  )
 
   if (nrow(data_raw) == 0) {
-    stop("No valid results from the API")
+    cli::cli_abort("No valid results from the API") # nocov
   }
 
   data <- data_raw[c("fecha", "indicativo", "tm_mes")]
   data <- data[!is.na(data$tm_mes), ]
   data <- data[grep("-13", data$fecha), ]
   data <- dplyr::rename(data, year = "fecha", temp = "tm_mes")
-  data <-
-    dplyr::mutate(data,
-      temp = as.numeric(data$temp),
-      year = as.integer(gsub("-13", "", data$year))
-    )
-
+  data <- dplyr::mutate(
+    data,
+    temp = as.numeric(data$temp),
+    year = as.integer(gsub("-13", "", data$year))
+  )
 
   stations <- aemet_stations(verbose = verbose)
   stations <- stations[stations$indicativo == station, ]
@@ -145,35 +147,48 @@ climatestripes_station <- function(station, start = 1950, end = 2020,
 #'   labs(subtitle = "(1950-2020)")
 #' }
 #' @export
-ggstripes <- function(data, plot_type = "stripes", plot_title = "",
-                      n_temp = 11, col_pal = "RdBu", ...) {
+ggstripes <- function(
+  data,
+  plot_type = "stripes",
+  plot_title = "",
+  n_temp = 11,
+  col_pal = "RdBu",
+  ...
+) {
   if (!is.numeric(n_temp)) {
-    stop("`n_temp` needs to be numeric")
+    cli::cli_abort(
+      "{.arg n_temp} needs to be numeric, not {.obj_type_friendly {n_temp}}."
+    )
   }
 
+  valid_types <- c("background", "stripes", "trend", "animation") # nolint
   if (!plot_type %in% c("background", "stripes", "trend", "animation")) {
-    stop(
-      "`plot_type` should be one of 'background', ",
-      "'stripes', 'trend', 'animation'"
+    cli::cli_abort(
+      paste0(
+        "{.arg plot_type} should be one of {.val {valid_types}}, ",
+        "not {.val {plot_type}}."
+      )
     )
   }
 
   if (!col_pal %in% hcl.pals()) {
-    stop("`col_pal` should be one of the palettes defined on `hcl.pals()`")
+    cli::cli_abort(
+      paste0(
+        "{.arg col_pal} should be one of the palettes ",
+        "defined on {.fn grDevices::hcl.pals}."
+      )
+    )
   }
 
   if (!"temp" %in% names(data) || !"year" %in% names(data)) {
-    stop("`data` must have  `year` and `temp` cols. ")
+    cli::cli_abort("{.arg data} must have  {.str year} and {.str temp} cols.")
   }
 
-
   # Missing values 999.9
-  data <-
-    dplyr::mutate(data, temp = ifelse(data$temp == 999.9, NA, data$temp))
+  data <- dplyr::mutate(data, temp = ifelse(data$temp == 999.9, NA, data$temp))
 
   # Formatting dates
-  data <-
-    dplyr::mutate(data, date = as.Date(first_day_of_year(data$year)))
+  data <- dplyr::mutate(data, date = as.Date(first_day_of_year(data$year)))
 
   # Create themes
   theme_strip <- ggplot2::theme_minimal() +
@@ -186,8 +201,8 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
       axis.text.x = element_text(vjust = 3),
       panel.grid.minor = element_blank(),
       plot.title = element_text(size = 14, face = "bold"),
-      plot.margin = ggplot2::unit(rep(15, 4), "pt"),
-      plot.caption = element_text(margin = ggplot2::unit(rep(3, 4), "pt"))
+      plot.margin = ggplot2::margin(15, 15, 15, 15),
+      plot.caption = element_text(margin = ggplot2::margin(3, 3, 3, 3))
     )
 
   theme_striptrend <- ggplot2::theme_minimal() +
@@ -209,7 +224,7 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
       plot.title = element_text(size = 14, face = "bold"),
       legend.background = element_rect(
         fill = "white",
-        size = 0.5,
+        linewidth = 0.5,
         linetype = "solid",
         colour = "black"
       ),
@@ -217,25 +232,22 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
         color = "black",
         face = "plain",
         size = 12,
-        margin = ggplot2::unit(rep(3, 4), "pt")
+        margin = ggplot2::margin(3, 3, 3, 3)
       ),
-      plot.margin = ggplot2::unit(rep(15, 4), "pt")
+      plot.margin = ggplot2::margin(15, 15, 15, 15)
     )
 
   # Create palette
   pal_strip <- hcl.colors(n_temp, col_pal)
 
-
   if (plot_type == "stripes") {
-    message("Climate stripes plotting ...")
+    cli::cli_alert_info("Climate stripes plotting ...")
 
     # Create climate stripes plot with labels----
-    striplotlab <-
-      ggplot(data, aes(
-        x = .data$date,
-        y = 1,
-        fill = .data$temp
-      )) +
+    striplotlab <- ggplot(
+      data,
+      aes(x = .data$date, y = 1, fill = .data$temp)
+    ) +
       ggplot2::geom_tile() +
       ggplot2::scale_x_date(
         date_breaks = "5 years",
@@ -253,17 +265,19 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
       theme_strip
 
     # Draw plot
-    return(striplotlab)
+    striplotlab
+
+    # nocov start
   } else if (plot_type == "trend") {
-    message("Climate stripes with temperature line trend plotting ...")
+    cli::cli_alert_info(
+      "Climate stripes with temperature line trend plotting ..."
+    )
 
     # Create climate stripes plot with line trend----
-    stripbackground <-
-      ggplot(data, aes(
-        x = .data$date,
-        y = 1,
-        fill = .data$temp
-      )) +
+    stripbackground <- ggplot(
+      data,
+      aes(x = .data$date, y = 1, fill = .data$temp)
+    ) +
       ggplot2::geom_tile(show.legend = FALSE) +
       ggplot2::scale_x_date(
         date_breaks = "5 years",
@@ -293,24 +307,21 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
     )
     # Read stripes plot for background
 
-    background <-
-      jpeg::readJPEG(file.path(tempdir(), "stripbrackground.jpeg"))
+    background <- jpeg::readJPEG(file.path(tempdir(), "stripbrackground.jpeg"))
 
     m <- mean(data$temp, na.rm = TRUE)
 
-    striplotrend <-
-      ggplot(data, aes(x = date, y = .data$temp)) +
-      ggplot2::geom_tile(aes(
-        x = .data$date,
-        y = m,
-        fill = .data$temp
-      )) +
+    striplotrend <- ggplot(data, aes(x = .data$date, y = .data$temp)) +
+      ggplot2::geom_tile(aes(x = .data$date, y = m, fill = .data$temp)) +
       # Overwrite with jpeg
-      ggplot2::annotation_raster(background, -Inf, Inf, -Inf, Inf) +
-      geom_line(aes(y = .data$temp),
-        color = "black",
-        size = 1
+      ggplot2::annotation_raster(
+        background,
+        min(data$date),
+        max(data$date),
+        -Inf,
+        Inf
       ) +
+      geom_line(aes(y = .data$temp), color = "black", linewidth = 1) +
       ggplot2::geom_smooth(
         method = "gam",
         formula = y ~ s(x),
@@ -331,22 +342,19 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
         title = plot_title,
         caption = "Source: Spanish Meteorological Agency (AEMET)"
       ) +
-      ggplot2::xlab("Date (Year)") +
-      ggplot2::ylab("Temperature (C)") +
+      ggplot2::labs(x = "Date (Year)", y = "Temperature (C)") +
       theme_striptrend
 
     # Draw plot
-    return(striplotrend)
+    striplotrend
   } else if (plot_type == "background") {
-    message("Climate stripes background plotting ...")
+    cli::cli_alert_info("Climate stripes background plotting ...")
 
     # Create climate stripes background----
-    stripbackground <-
-      ggplot(data, aes(
-        x = .data$date,
-        y = 1,
-        fill = .data$temp
-      )) +
+    stripbackground <- ggplot(
+      data,
+      aes(x = .data$date, y = 1, fill = .data$temp)
+    ) +
       ggplot2::geom_tile(show.legend = FALSE) +
       ggplot2::scale_x_date(
         date_breaks = "5 years",
@@ -362,27 +370,26 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
       ggplot2::theme_void()
 
     # Draw plot
-    return(stripbackground)
+    stripbackground
   } else {
-    message("Climate stripes animation ...")
+    cli::cli_alert_info("Climate stripes animation ...")
 
     # Create climate stripes plot animation----
     # Create climate stripes background
     if (!requireNamespace("jpeg", quietly = TRUE)) {
-      stop("\n\npackage jpeg required, please install it first")
+      cli::cli_abort("package {.pkg jpeg} required, please install it first.")
     }
 
     if (!requireNamespace("gganimate", quietly = TRUE)) {
-      stop("\n\npackage gganimate required, please install it first")
+      cli::cli_abort(
+        "package {.pkg gganimate} required, please install it first."
+      )
     }
 
-
-    stripbackground <-
-      ggplot(data, aes(
-        x = .data$date,
-        y = 1,
-        fill = .data$temp
-      )) +
+    stripbackground <- ggplot(
+      data,
+      aes(x = .data$date, y = 1, fill = .data$temp)
+    ) +
       ggplot2::geom_tile(show.legend = FALSE) +
       ggplot2::scale_x_date(
         date_breaks = "5 years",
@@ -412,13 +419,11 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
     )
     # Read stripes plot for background
 
-    background <-
-      jpeg::readJPEG(file.path(tempdir(), "stripbrackground.jpeg"))
+    background <- jpeg::readJPEG(file.path(tempdir(), "stripbrackground.jpeg"))
 
-    striplotanimation <-
-      ggplot(data, aes(x = .data$date, y = .data$temp)) +
+    striplotanimation <- ggplot(data, aes(x = .data$date, y = .data$temp)) +
       ggplot2::annotation_raster(background, -Inf, Inf, -Inf, Inf) +
-      geom_line(size = 1.5, color = "yellow") +
+      geom_line(linewidth = 1.5, color = "yellow") +
       ggplot2::scale_x_date(
         date_breaks = "5 years",
         date_minor_breaks = "5 years",
@@ -433,19 +438,21 @@ ggstripes <- function(data, plot_type = "stripes", plot_title = "",
         title = plot_title,
         caption = "Source: Spanish Meteorological Agency (AEMET)"
       ) +
-      ggplot2::xlab("Year") +
-      ggplot2::ylab("Temperature (C)") +
+      ggplot2::labs(x = "Year", y = "Temperature (C)") +
       theme_striptrend +
       gganimate::transition_reveal(date)
 
-    # Draw plot
-    return(striplotanimation)
+    cli::cli_alert_success("Done! See {.fn gganimate::anim_save} for save plot")
 
-    message("Done! ... Read gganimate::animate help for save plot")
+    # Draw plot
+    striplotanimation
   }
 
-  # Clear environment except function
-  rm(list = ls(all.names = TRUE))
+  # nocov end
 }
 
-# nocov end
+
+#' @export
+#' @rdname climatestripes_station
+#' @usage NULL
+ggstripes_station <- climatestripes_station
