@@ -1,5 +1,3 @@
-# nocov start
-
 #' Windrose (speed/direction) diagram of a station over a days period
 #'
 #' @description
@@ -31,26 +29,31 @@
 #' )
 #' @export
 
-windrose_days <- function(station, start = "2000-12-01", end = "2000-12-31",
-                          n_directions = 8, n_speeds = 5, speed_cuts = NA,
-                          col_pal = "GnBu", calm_wind = 0,
-                          legend_title = "Wind Speed (m/s)", verbose = FALSE) {
-  message("Data download may take a few seconds ... please wait \n")
+windrose_days <- function(
+  station,
+  start = "2000-12-01",
+  end = "2000-12-31",
+  n_directions = 8,
+  n_speeds = 5,
+  speed_cuts = NA,
+  col_pal = "GnBu",
+  calm_wind = 0,
+  legend_title = "Wind Speed (m/s)",
+  verbose = FALSE
+) {
+  cli::cli_alert_info("Data download may take a few seconds ... please wait.")
 
-  data_raw <-
-    aemet_daily_clim(
-      station = station,
-      start = start,
-      end = end,
-      verbose = verbose
-    )
+  data_raw <- aemet_daily_clim(
+    station = station,
+    start = start,
+    end = end,
+    verbose = verbose
+  )
 
   data <- data_raw[c("fecha", "dir", "velmedia")]
   data <- tidyr::drop_na(data)
-  data <-
-    dplyr::mutate(data, dir = as.numeric(data[["dir"]]) * 10)
-  data <-
-    dplyr::filter(data, data[["dir"]] >= 0 & data[["dir"]] <= 360)
+  data <- dplyr::mutate(data, dir = as.numeric(data[["dir"]]) * 10)
+  data <- dplyr::filter(data, data[["dir"]] >= 0 & data[["dir"]] <= 360)
 
   speed <- data$velmedia
   direction <- data$dir
@@ -118,23 +121,26 @@ windrose_days <- function(station, start = "2000-12-01", end = "2000-12-31",
 #' }
 #' @export
 
-windrose_period <- function(station, start = 2000, end = 2010, n_directions = 8,
-                            n_speeds = 5, speed_cuts = NA, col_pal = "GnBu",
-                            calm_wind = 0, legend_title = "Wind Speed (m/s)",
-                            verbose = FALSE) {
-  message("Data download may take a few minutes ... please wait \n")
+windrose_period <- function(
+  station,
+  start = 2000,
+  end = 2010,
+  n_directions = 8,
+  n_speeds = 5,
+  speed_cuts = NA,
+  col_pal = "GnBu",
+  calm_wind = 0,
+  legend_title = "Wind Speed (m/s)",
+  verbose = FALSE
+) {
+  cli::cli_alert_info("Data download may take a few seconds ... please wait.")
 
-  data_raw <- aemet_daily_period(station,
-    start, end,
-    verbose = verbose
-  )
+  data_raw <- aemet_daily_period(station, start, end, verbose = verbose)
 
   data <- data_raw[c("fecha", "dir", "velmedia")]
   data <- tidyr::drop_na(data)
-  data <-
-    dplyr::mutate(data, dir = as.numeric(data[["dir"]]) * 10)
-  data <-
-    dplyr::filter(data, data[["dir"]] >= 0 & data[["dir"]] <= 360)
+  data <- dplyr::mutate(data, dir = as.numeric(data[["dir"]]) * 10)
+  data <- dplyr::filter(data, data[["dir"]] >= 0 & data[["dir"]] <= 360)
 
   speed <- data$velmedia
   direction <- data$dir
@@ -247,30 +253,73 @@ windrose_period <- function(station, start = 2000, end = 2010, n_directions = 8,
 #'   )
 #'
 #' @export
-ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
-                       speed_cuts = NA, col_pal = "GnBu",
-                       legend_title = "Wind speed (m/s)", calm_wind = 0,
-                       n_col = 1, facet = NULL, plot_title = "",
-                       stack_reverse = FALSE,
-                       ...) {
-  if (missing(speed)) {
-    stop("Speed can't be missing")
+ggwindrose <- function(
+  speed,
+  direction,
+  n_directions = 8,
+  n_speeds = 5,
+  speed_cuts = NA,
+  col_pal = "GnBu",
+  legend_title = "Wind speed (m/s)",
+  calm_wind = 0,
+  n_col = 1,
+  facet = NULL,
+  plot_title = "",
+  stack_reverse = FALSE,
+  ...
+) {
+  if (any(missing(speed), !is.numeric(speed))) {
+    cli::cli_abort(
+      paste0(
+        "{.arg speed} needs to be numeric, ",
+        "not {.obj_type_friendly {speed}}."
+      )
+    )
   }
 
-  if (missing(direction)) {
-    stop("Direction can't be missing")
+  if (any(missing(direction), !is.numeric(direction))) {
+    cli::cli_abort(
+      paste0(
+        "{.arg direction} needs to be numeric, ",
+        "not {.obj_type_friendly {direction}}."
+      )
+    )
+  }
+
+  if (length(speed) != length(direction)) {
+    cli::cli_abort(
+      paste0(
+        "{.arg direction} and {.arg speed} should have the same ",
+        "lenght ({length(direction)} vs. {length(speed)})."
+      )
+    )
+  }
+
+  if (any((direction > 360 | direction < 0), na.rm = TRUE)) {
+    cli::cli_abort(
+      "{.arg direction} should be between 0 and 360, not {direction}"
+    )
   }
 
   if (!is.logical(stack_reverse)) {
-    stop("`stack_reverse` should be `TRUE` or `FALSE`")
+    cli::cli_abort(
+      paste0(
+        "{.arg stack_reverse} needs to be logical, ",
+        "not {.obj_type_friendly {stack_reverse}}."
+      )
+    )
   }
 
-
   include_facet <- !is.null(facet)
 
   if (include_facet) {
-    if (!is.character(facet) && !is.factor(facet)) {
-      stop("The facet variable needs to be character or factor")
+    if (!any(is.character(facet), is.factor(facet))) {
+      cli::cli_abort(
+        paste0(
+          "{.arg facet} needs to be character or factor, ",
+          "not {.obj_type_friendly {facet}}."
+        )
+      )
     }
 
     if (length(facet) == 1) {
@@ -278,64 +327,84 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
     }
 
     if (length(facet) != length(speed)) {
-      stop("The facet variable must be the same length as the wind speeds")
+      cli::cli_abort(
+        paste0(
+          "{.arg facet} and {.arg speed} should have the same ",
+          "lenght ({length(facet)} vs. {length(speed)})."
+        )
+      )
     }
   }
 
-  if (!is.numeric(speed)) {
-    stop("Wind speeds need to be numeric")
-  }
-
-  if (!is.numeric(direction)) {
-    stop("Wind directions need to be numeric")
-  }
-
-  if (length(speed) != length(direction)) {
-    stop("Wind speeds and directions must be the same length")
-  }
-
-  if (any((direction > 360 | direction < 0),
-    na.rm = TRUE
-  )) {
-    stop("Wind directions can't be outside the interval [0, 360]")
-  }
-
   if (!is.numeric(n_directions) || length(n_directions) != 1) {
-    stop("n_directions must be a numeric vector of length 1")
+    cli::cli_abort(
+      paste0(
+        "{.arg n_directions} should be a numeric vector of length 1, not ",
+        "{.obj_type_friendly {n_directions}} of length {length(n_directions)}."
+      )
+    )
   }
 
   if (!is.numeric(n_speeds) || length(n_speeds) != 1) {
-    stop("n_speeds must be a numeric vector of length 1")
+    cli::cli_abort(
+      paste0(
+        "{.arg n_speeds} should be a numeric vector of length 1, not ",
+        "{.obj_type_friendly {n_speeds}} of length {length(n_speeds)}."
+      )
+    )
   }
 
   if (!is.numeric(calm_wind) || length(calm_wind) != 1) {
-    stop("calm_wind must be a numeric vector of length 1")
+    cli::cli_abort(
+      paste0(
+        "{.arg calm_wind} should be a numeric vector of length 1, not ",
+        "{.obj_type_friendly {calm_wind}} of length {length(calm_wind)}."
+      )
+    )
   }
 
-  if ((!is.character(legend_title) && !is.expression(
-    legend_title
-  )) || length(legend_title) != 1) {
-    stop("Legend title must be a single character string or expression")
+  if (
+    (!is.character(legend_title) &&
+      !is.expression(
+        legend_title
+      )) ||
+      length(legend_title) != 1
+  ) {
+    cli::cli_abort(
+      paste0(
+        "{.arg legend_title} should be a single character string or expression",
+        "not {.obj_type_friendly {legend_title}}."
+      )
+    )
   }
 
-
   if (!col_pal %in% hcl.pals()) {
-    stop("`col_pal` should be one of the palettes defined on `hcl.pals()`")
+    cli::cli_abort(
+      paste0(
+        "{.arg col_pal} should be one of the palettes ",
+        "defined on {.fn grDevices::hcl.pals}."
+      )
+    )
   }
 
   if (any(!is.na(speed_cuts)) && !is.numeric(speed_cuts)) {
-    stop("`speed_cuts` should be numeric or NA")
+    cli::cli_abort(
+      paste0(
+        "{.arg speed_cuts} should be numeric or NA, ",
+        "not {.obj_type_friendly {speed_cuts}}."
+      )
+    )
   }
 
   optimal_n_dir <- c(4, 8, 16)
 
   if (is.na(match(n_directions, optimal_n_dir))) {
-    n_directions <-
-      optimal_n_dir[which.min(abs(n_directions - optimal_n_dir))]
-    message(
-      "Using the closest optimal number of wind directions (",
-      n_directions,
-      ")"
+    n_directions <- optimal_n_dir[which.min(abs(n_directions - optimal_n_dir))]
+    cli::cli_alert_info(
+      paste0(
+        "Using the closest optimal number of wind directions ",
+        "({.val {n_directions}})."
+      )
     )
   }
 
@@ -343,23 +412,35 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
     "4" = c("N", "E", "S", "W"),
     "8" = c("N", "NE", "E", "SE", "S", "SW", "W", "NW"),
     "16" = c(
-      "N", "NNE", "NE", "ENE", "E", "ESE", "SE", "SSE", "S", "SSW", "SW",
-      "WSW", "W", "WNW", "NW", "NNW"
+      "N",
+      "NNE",
+      "NE",
+      "ENE",
+      "E",
+      "ESE",
+      "SE",
+      "SSE",
+      "S",
+      "SSW",
+      "SW",
+      "WSW",
+      "W",
+      "WNW",
+      "NW",
+      "NNW"
     )
   )
 
   # Factor variable for wind direction intervals
   dir_bin_width <- 360 / n_directions
-  dir_bin_cuts <-
-    seq(dir_bin_width / 2, 360 - dir_bin_width / 2, dir_bin_width)
-  dir_intervals <-
-    findInterval(c(direction, dir_bin_cuts), dir_bin_cuts)
+  dir_bin_cuts <- seq(dir_bin_width / 2, 360 - dir_bin_width / 2, dir_bin_width)
+  dir_intervals <- findInterval(c(direction, dir_bin_cuts), dir_bin_cuts)
   dir_intervals[dir_intervals == n_directions] <- 0
-  factor_labs <-
-    paste(c(tail(dir_bin_cuts, 1), head(dir_bin_cuts, -1)),
-      dir_bin_cuts,
-      sep = ", "
-    )
+  factor_labs <- paste(
+    c(tail(dir_bin_cuts, 1), head(dir_bin_cuts, -1)),
+    dir_bin_cuts,
+    sep = ", "
+  )
   dir_bin <- head(
     factor(dir_intervals, labels = paste0("(", factor_labs, "]")),
     -n_directions
@@ -383,16 +464,13 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
     spd_bin <- ggplot2::cut_interval(speed, n_speeds)
   }
 
-
   # If reverse then reverse also factors
   if (stack_reverse) {
     spd_bin <- factor(spd_bin, levels = rev(levels(spd_bin)))
   }
 
-
   # New palette
-  spd_cols <-
-    hcl.colors(length(levels(spd_bin)), col_pal, rev = !stack_reverse)
+  spd_cols <- hcl.colors(length(levels(spd_bin)), col_pal, rev = !stack_reverse)
 
   if (length(spd_cols) != length(levels(spd_bin))) {
     spd_bin <- ggplot2::cut_interval(speed, length(spd_cols))
@@ -404,7 +482,8 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
     ggplot_df$proportion <- unlist(
       by(
         ggplot_df$Freq,
-        ggplot_df$facet, function(x) {
+        ggplot_df$facet,
+        function(x) {
           x / sum(x)
         }
       ),
@@ -419,10 +498,10 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
 
   windrose_plot <- ggplot2::ggplot(
     data = ggplot_df,
-    ggplot2::aes_string(
-      x = "dir_bin",
-      fill = "spd_bin",
-      y = "proportion"
+    ggplot2::aes(
+      x = .data$dir_bin,
+      fill = .data$spd_bin,
+      y = .data$proportion
     )
   ) +
     ggplot2::geom_bar(stat = "identity") +
@@ -437,10 +516,12 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
       expand = FALSE
     ) +
     ggplot2::scale_y_continuous(
+      # nocov start
       labels = function(values) {
         values <- sprintf("%0.1f %%", values * 100)
         values
       }
+      # nocov end
     ) +
     ggplot2::theme_minimal() +
     ggplot2::theme(
@@ -452,17 +533,15 @@ ggwindrose <- function(speed, direction, n_directions = 8, n_speeds = 5,
     ggplot2::labs(title = plot_title)
 
   if (stack_reverse) {
-    windrose_plot <- windrose_plot + ggplot2::guides(
-      fill = ggplot2::guide_legend(reverse = TRUE)
-    )
+    windrose_plot <- windrose_plot +
+      ggplot2::guides(
+        fill = ggplot2::guide_legend(reverse = TRUE)
+      )
   }
 
   if (include_facet) {
-    windrose_plot <-
-      windrose_plot + ggplot2::facet_wrap(~facet, ncol = n_col)
+    windrose_plot <- windrose_plot + ggplot2::facet_wrap(~facet, ncol = n_col)
   }
 
-  return(windrose_plot)
+  windrose_plot
 }
-
-# nocov end
